==> inettools-0.1.tar.gz: inettools-0.1/rdate.c <==
/*
 * rdate.c
 */

__asm("	text\n	dc.b	'$Id: rdate.c,v 1.1 1998/10/14 19:13:18 sharl Exp $'\n	even\n");

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <ctype.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <netdb.h>
#include <errno.h>
#include <sys/time.h>
#include <time.h>

#define DIFFERENCE 2208988800UL

char *__progname;

static void
usage()
{
	fprintf(stderr, "Usage: %s [-psav] host\n", __progname);
	fprintf(stderr, "  -p: just print, don't set\n");
	fprintf(stderr, "  -s: just set, don't print\n");
	fprintf(stderr, "  -a: use adjtime instead of instant change\n");
	fprintf(stderr, "  -v: print version\n");
}

int
main(int argc, char *argv[])
{
	struct sockaddr_in saddr;
	struct hostent *shost;
	struct servent *serv, sserv;
	time_t tim;
	char *host;
	char *p;
	int sock;
	int c, pr = 0, silent = 0, slidetime = 0, adjustment = 0;

	__progname = argv[0];

	while ((c = getopt(argc, argv, "psav")) != EOF) {
		switch (c) {
			case 'p':
				pr++;
				break;
			case 's':
				silent++;
				break;
			case 'a':
				slidetime++;
				break;
			case 'v':
				fprintf(stderr, "%s " VERSION " (" PACKAGE ") (C)1998 Sharl <sharl@www.ufo.co.jp>\n", __progname);
				return EXIT_SUCCESS;
			default:
				usage();
				return EXIT_FAILURE;
		}
	}

	if (argc - 1 != optind) {
		usage();
		return EXIT_FAILURE;
	}
	host = argv[optind];

	if ((serv = getservbyname("time", "tcp")) == NULL) {
		serv = &sserv;
		serv->s_port = 37;
	}
	memset(&saddr, 0, sizeof(saddr));
	if (isipaddr(host)) {
		saddr.sin_addr.s_addr = inet_addr(host);
		if ((shost = gethostbyaddr((char *)&saddr.sin_addr,
				sizeof(saddr.sin_addr), AF_INET)) == NULL) {
			fprintf(stderr, "gethostbyaddr() failed.\n");
			return EXIT_FAILURE;
		}
		host = shost->h_name;
	} else {
		shost = gethostbyname(host);
		if (shost) {
			memcpy(&saddr.sin_addr, shost->h_addr, shost->h_length);
		} else {
			fprintf(stderr, "%s: host name lookup failed.\n", host);
			return EXIT_FAILURE;
		}
	}

	saddr.sin_family = AF_INET;
	saddr.sin_port = htons(serv->s_port);

	if ((sock = socket(AF_INET, SOCK_STREAM, 0)) < 0) {
		fprintf(stderr, "can't create socket.\n");
		return 1;
	}
	if (connect(sock, (struct sockaddr *)&saddr, sizeof(struct sockaddr)) < 0) {
		fprintf(stderr, "%s: unable to connect: %s\n", host, strerror(errno));
		return EXIT_FAILURE;
	}
	if (read(sock, &tim, sizeof(time_t)) != sizeof(time_t)) {
		fprintf(stderr, "%s: %s (Could not read data)\n", host, strerror(errno));
		return EXIT_FAILURE;
	}
	close(sock);

	tim = ntohl(tim) - DIFFERENCE;
	if (!pr) {
		struct timeval tv;

		if (!slidetime) {
			tv.tv_sec = tim;
			tv.tv_usec = 0;
			if (settimeofday(&tv, NULL) == -1) {
				fprintf(stderr, "Could not set time of day\n");
				return EXIT_FAILURE;
			}
		} else {
		    struct timeval tv_current;

		    if (gettimeofday(&tv_current, NULL) == -1)
			    err(1, "Could not get local time of day");
		    adjustment = tv.tv_sec = tim - tv_current.tv_sec;
		    tv.tv_usec = 0;
		    if (adjtime(&tv, NULL) == -1) {
			    fprintf(stderr, "Could not adjust time of day\n");
				return EXIT_FAILURE;
			}
		}
	}
	if (!silent) {
		printf(ctime(&tim));
		if (slidetime)
		    printf("%s: adjust local clock by %d seconds\n", __progname, adjustment);
	}
	return EXIT_SUCCESS;
}

==> inettools-0.2.tar.gz: inettools-0.2/rdate.c <==
/*
 * rdate.c
 */

__asm("	text\n	dc.b	'$Id: rdate.c,v 1.2 1998/10/17 08:29:32 sharl Exp $'\n	even\n");

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <unistd.h>
#include <arpa/nameser.h>
#include <err.h>
#include <errno.h>
#include <sys/time.h>
#include <time.h>
#include "author.h"
#include "socksub.h"

#define DIFFERENCE 2208988800UL

char *__progname;

static void
usage()
{
	fprintf(stderr, "Usage: %s [-psav] host\n", __progname);
	fprintf(stderr, "  -p: just print, don't set\n");
	fprintf(stderr, "  -s: just set, don't print\n");
	fprintf(stderr, "  -a: use adjtime instead of instant change\n");
	fprintf(stderr, "  -v: print version\n");
}

int
main(int argc, char *argv[])
{
	time_t tim;
	char *host;
	int sock;
	int c, pr = 0, silent = 0, slidetime = 0, adjustment = 0;

	__progname = argv[0];

	while ((c = getopt(argc, argv, "psav")) != EOF) {
		switch (c) {
			case 'p':
				pr++;
				break;
			case 's':
				silent++;
				break;
			case 'a':
				slidetime++;
				break;
			case 'v':
				fprintf(stderr, "%s (" PACKAGE " " VERSION ") (C)1998 " AUTHOR "\n", __progname);
				return EXIT_SUCCESS;
			default:
				usage();
				return EXIT_FAILURE;
		}
	}

	if (argc - 1 != optind) {
		usage();
		return EXIT_FAILURE;
	}
	host = argv[optind];

	sock = connect_sub(host, "time", "tcp", 37);
	if (sock < 0)
		return EXIT_FAILURE;
	if (read(sock, &tim, sizeof(time_t)) != sizeof(time_t)) {
		fprintf(stderr, "%s: %s (Could not read data)\n", host, strerror(errno));
		return EXIT_FAILURE;
	}
	close(sock);

	tim = ntohl(tim) - DIFFERENCE;
	if (!pr) {
		struct timeval tv;

		if (!slidetime) {
			tv.tv_sec = tim;
			tv.tv_usec = 0;
			if (settimeofday(&tv, NULL) == -1) {
				fprintf(stderr, "Could not set time of day\n");
				return EXIT_FAILURE;
			}
		} else {
		    struct timeval tv_current;

		    if (gettimeofday(&tv_current, NULL) == -1)
			    err(EXIT_FAILURE, "Could not get local time of day");
		    adjustment = tv.tv_sec = tim - tv_current.tv_sec;
		    tv.tv_usec = 0;
		    if (adjtime(&tv, NULL) == -1) {
			    fprintf(stderr, "Could not adjust time of day\n");
				return EXIT_FAILURE;
			}
		}
	}
	if (!silent) {
		printf(ctime(&tim));
		if (slidetime)
		    printf("%s: adjust local clock by %d seconds\n", __progname, adjustment);
	}
	return EXIT_SUCCESS;
}
